"""
Join objects from multiple sources into a single stream
"""
from functools import partial
from typing import Iterable, TypeVar

T = TypeVar("T")  # pylint: disable=invalid-name


def combinator_take(items: Iterable[T], count: int) -> Iterable[T]:
    "Retrieve the first `count` items from an iterator"
    observed = 0
    for item in items:
        observed += 1
        yield item

        if observed >= count:
            break


combinator_first = partial(combinator_take, count=1)


def combinator_join(*args: Iterable[T]) -> Iterable[T]:
    "Join the results of many album producers by exhausting all albums from each producer"

    for arg in args:
        for item in arg:
            yield item
